---
name: Bug report
about: Scanpy doesn’t do what it should? Please help us fix it!
title: ''
labels: bug
assignees: ''
---

- [ ] I have checked that this issue has not already been reported.
- [ ] I have confirmed this bug exists on the latest version of scanpy.
- [ ] (optional) I have confirmed this bug exists on the master branch of scanpy.

---

**Note**: Please read [this guide](https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports) detailing how to provide the necessary information for us to reproduce your bug.


### Minimal code sample (that we can copy&paste without having any data)

```python
# Your code here
```

```pytb
[Paste the error output produced by the above code here]
```

#### Versions

<details>

[Paste the output of scanpy.logging.print_versions() leaving a blank line after the details tag]

</details>
